@@ -22,28 +22,29 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <include/base/file/files_utility.h>
 
 #ifndef WIN32
-extern "C" {
-#include <fcntl.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <errno.h>
-#include <stdio.h>
-#include <fcntl.h>
-#include <stdlib.h>
-#include <string.h>
-#include <math.h>
-#include <time.h>
+extern "C"
+{
+# include <fcntl.h>
+# include <unistd.h>
+# include <sys/types.h>
+# include <sys/stat.h>
+# include <errno.h>
+# include <stdio.h>
+# include <fcntl.h>
+# include <stdlib.h>
+# include <string.h>
+# include <math.h>
+# include <time.h>
 
-#ifdef SENDFILE
-#include <fcntl.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <sys/sendfile.h>
-#include <sys/stat.h>
-#include <sys/types.h>
-#include <unistd.h>
-#endif
+# ifdef SENDFILE
+#  include <fcntl.h>
+#  include <stdlib.h>
+#  include <stdio.h>
+#  include <sys/sendfile.h>
+#  include <sys/stat.h>
+#  include <sys/types.h>
+#  include <unistd.h>
+# endif
 
 
 }
@@ -68,9 +69,17 @@ const u_long File::NO_INHERIT = (1<<8);
 /*!
  *Costructor of the class.
  */
-File::File()
+File::File ()
 {
-  handle = 0;
+  handle = (FileHandle) -1;
+}
+
+/*!
+ *D'tor.
+ */
+File::~File ()
+{
+  close ();
 }
 
 /*!
@@ -83,7 +92,7 @@ File::File()
  *\param buffersize The length of the buffer in bytes.
  *\param nbw How many bytes were written to the file.
  */
-int File::writeToFile(const char* buffer, u_long buffersize, u_long* nbw)
+int File::writeToFile (const char* buffer, u_long buffersize, u_long* nbw)
 {
   if (buffersize == 0)
   {
@@ -105,7 +114,7 @@ int File::writeToFile(const char* buffer, u_long buffersize, u_long* nbw)
  *\param opt Specify how open the file.
  */
 File::File (char *nfilename, int opt)
-  : handle (0)
+  : handle ((FileHandle)-1)
 {
   openFile (nfilename, opt);
 }
@@ -170,7 +179,7 @@ int File::openFile (const char* nfilename,u_long opt)
 
   if (opt & File::TEMPORARY)
   {
-    openFlag |= FILE_ATTRIBUTE_TEMPORARY; 
+    openFlag |= FILE_ATTRIBUTE_TEMPORARY;
     attributeFlag |= FILE_FLAG_DELETE_ON_CLOSE;
   }
   if (opt & File::HIDDEN)
@@ -179,13 +188,13 @@ int File::openFile (const char* nfilename,u_long opt)
   if (attributeFlag == 0)
     attributeFlag = FILE_ATTRIBUTE_NORMAL;
 
-  handle = CreateFile(filename.c_str (), openFlag,
-                      FILE_SHARE_READ|FILE_SHARE_WRITE,
-                      &sa, creationFlag, attributeFlag, NULL);
+  handle = CreateFile (filename.c_str (), openFlag,
+                       FILE_SHARE_READ|FILE_SHARE_WRITE,
+                       &sa, creationFlag, attributeFlag, NULL);
 
   if (handle == INVALID_HANDLE_VALUE)
     {
-      filename.clear();
+      filename.clear ();
       return 1;
     }
   else
@@ -197,8 +206,8 @@ int File::openFile (const char* nfilename,u_long opt)
 
       if (ret)
         {
-          close();
-          filename.clear();
+          close ();
+          filename.clear ();
           return 1;
         }
     }
@@ -235,14 +244,14 @@ int File::openFile (const char* nfilename,u_long opt)
 
   return handle < 0;
 #endif
-  
+
   return 0;
 }
 
 /*!
- *Returns the base/file/file.handle.
+ *Returns the file handle.
  */
-Handle File::getHandle()
+Handle File::getHandle ()
 {
   return (Handle) handle;
 }
@@ -252,7 +261,7 @@ Handle File::getHandle()
  *Return a non null-value on errors.
  *\param hl The new base/file/file.handle.
  */
-int File::setHandle(Handle hl)
+int File::setHandle (Handle hl)
 {
   handle = (FileHandle) hl;
   return 0;
@@ -274,16 +283,16 @@ int File::operator =(File f)
  *Return Non-zero on errors.
  *\param nfilename The new file name.
  */
-int File::setFilename(const char* nfilename)
+int File::setFilename (const char* nfilename)
 {
-  filename.assign(nfilename);
+  filename.assign (nfilename);
   return 0;
 }
 
 /*!
  *Returns the file path.
  */
-const char *File::getFilename()
+const char *File::getFilename ()
 {
   return filename.c_str ();
 }
@@ -292,25 +301,25 @@ const char *File::getFilename()
  *Create a temporary file.
  *\param filename The new temporary file name.
  */
-int File::createTemporaryFile(const char* filename)
-{ 
-  if (FilesUtility::fileExists(filename))
-    FilesUtility::deleteFile(filename);
+int File::createTemporaryFile (const char* filename)
+{
+  if (FilesUtility::fileExists (filename))
+    FilesUtility::deleteFile (filename);
 
-  return openFile(filename, File::READ | 
-                  File::WRITE| 
-                  File::FILE_CREATE_ALWAYS |
-                  File::TEMPORARY |
-                  File::NO_INHERIT);
+  return openFile (filename, File::READ
+                  | File::WRITE
+                  | File::FILE_CREATE_ALWAYS
+                  | File::TEMPORARY
+                  | File::NO_INHERIT);
 }
 
 /*!
- *Close an open base/file/file.handle.
+ * Close the file.
  */
-int File::close()
+int File::close ()
 {
   int ret = 0;
-  if (handle)
+  if (handle != (FileHandle) -1)
     {
 #ifdef WIN32
       ret = !FlushFileBuffers (handle);
@@ -320,30 +329,27 @@ int File::close()
       ret |= ::close (handle);
 #endif
   }
-  filename.clear();
-  handle = 0;
+  filename.clear ();
+  handle = (FileHandle) -1;
   return ret;
 }
 
 /*!
- *Returns the file size in bytes.
- *Returns -1 on errors.
+ * Returns the file size in bytes.
+ * Returns -1 on errors.
  */
-u_long File::getFileSize()
+u_long File::getFileSize ()
 {
   u_long ret;
 #ifdef WIN32
-  ret = GetFileSize(handle, NULL);
+  ret = GetFileSize (handle, NULL);
   if (ret != INVALID_FILE_SIZE)
-  {
     return ret;
-  }
   else
     return (u_long)-1;
 #else
   struct stat fStats;
   ret = fstat (handle, &fStats);
-
   if (ret)
     return (u_long)(-1);
   else
@@ -392,9 +398,9 @@ time_t File::getLastModTime ()
 /*!
  *This function returns the creation time of the file.
  */
-time_t File::getCreationTime()
+time_t File::getCreationTime ()
 {
-  return FilesUtility::getCreationTime(filename);
+  return FilesUtility::getCreationTime (filename);
 }
 
 /*!
@@ -410,10 +416,7 @@ time_t File::getLastAccTime ()
  */
 int File::write (const char* buffer, u_long len, u_long *nbw)
 {
-  int ret = writeToFile (buffer, len, nbw );
-  if (ret != 0)
-    return -1;
-  return 0;
+  return writeToFile (buffer, len, nbw );
 }
 
 /*!
@@ -427,12 +430,11 @@ int File::write (const char* buffer, u_long len, u_long *nbw)
 int File::read (char* buffer, u_long buffersize, u_long* nbr)
 {
 #ifdef WIN32
-  int ret = ReadFile((HANDLE)handle, buffer, buffersize, nbr, NULL);
-  return (!ret);
+  return !ReadFile (handle, buffer, buffersize, nbr, NULL);
 #else
-  int ret  = ::read((long)handle, buffer, buffersize);
-  *nbr = (u_long)ret;
-  return (ret == -1) ;
+  int ret  = ::read (handle, buffer, buffersize);
+  *nbr = (u_long) ret;
+  return (ret == -1);
 #endif
 }
 
@@ -455,7 +457,6 @@ int File::fastCopyToSocket (Socket *dest, u_long firstByte, MemBuf *buf, u_long
     {
       int ret = sendfile (dest->getHandle (), getHandle (), &offset,
                           fileSize - offset);
-
       if (ret < 0)
         {
           /* Rollback to read/write on EINVAL or ENOSYS.  */
