@@ -1,19 +1,22 @@
 /*
-MyServer
-Copyright (C) 2005, 2007, 2008, 2009 Free Software Foundation, Inc.
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 3 of the License, or
-(at your option) any later version.
+  MyServer
+  Copyright (C) 2005, 2007, 2008, 2009 Free Software Foundation, Inc.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
 
-This program is distributed in the hope that it will be useful, 
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
+
+#include "stdafx.h"
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
 #include <include/protocol/http/http_headers.h>
 #include <include/protocol/http/http.h>
 #include <include/protocol/http/http_data_handler.h>
@@ -26,7 +29,7 @@ HttpDataHandler::send (HttpThreadContext* td,
                        const char* /*filenamePath*/, const char* /*exec*/,
                        bool /*execute*/, bool /*onlyHeader*/)
 {
-  td->connection->host->warningsLogWrite ("HttpDataHandler: using the base interface!");
+  td->connection->host->warningsLogWrite (_("HttpDataHandler: using the base interface!"));
   return td->http->raiseHTTPError (500);
 }
 
@@ -99,21 +102,21 @@ int HttpDataHandler::appendDataToHTTPChannel (HttpThreadContext* td,
 
   if (chain->write (buffer, size, &nbw))
     {
-      td->connection->host->warningsLogWrite ("HTTP<DATA HANDLER ERROR>: unable to write data in the buffer.");
+      td->connection->host->warningsLogWrite (_("Http: internal error"));
       return 1;
     }
 
 
   if (tmpStream->read (buffer, realBufferSize, &nbr))
     {
-      td->connection->host->warningsLogWrite ("HTTP<DATA HANDLER ERROR>: unable to read data from the buffer.");
+      td->connection->host->warningsLogWrite (_("Http: internal error"));
       return 1;
     }
 
   chain->setStream (oldStream);
 
   /*
-   *Use of chain->getStream() is needed to write directly on the
+   *Use of chain->getStream () is needed to write directly on the
    *final stream.
    */
   return appendDataToHTTPChannel (td, buffer, nbr, appendFile, chain, append,
@@ -132,19 +135,15 @@ int HttpDataHandler::appendDataToHTTPChannel (HttpThreadContext* td,
  * \param useChunks Can we use HTTP chunks to send data?
  */
 int
-HttpDataHandler::appendDataToHTTPChannel (HttpThreadContext* td,
-                                          char* buffer,
-                                          u_long size,
-                                          File* appendFile,
-                                          FiltersChain* chain,
-                                          bool append,
-                                          bool useChunks)
+HttpDataHandler::appendDataToHTTPChannel (HttpThreadContext* td, char* buffer,
+                           u_long size, File* appendFile, FiltersChain* chain,
+                                          bool append, bool useChunks)
 {
   u_long nbw;
 
   if (chain->hasModifiersFilters ())
     {
-      td->connection->host->warningsLogWrite ("HTTP<DATA HANDLER ERROR>: Filter chain has modifiers filters.");
+      td->connection->host->warningsLogWrite (_("Http: internal error"));
       return 1;
     }
 
@@ -160,27 +159,27 @@ HttpDataHandler::appendDataToHTTPChannel (HttpThreadContext* td,
 
           if (chain->flush (&flushNbw))
             {
-              td->connection->host->warningsLogWrite ("HTTP<DATA HANDLER ERROR>: unable to flush data.");
+              td->connection->host->warningsLogWrite (_("Http: internal error"));
               return 1;
             }
 
           if (chain->getStream ()->write (chunkHeader.str ().c_str (),
                                           chunkHeader.str ().length (), &nbw))
             {
-              td->connection->host->warningsLogWrite ("HTTP<DATA HANDLER ERROR>: unable to write data in the filters chain.");
+              td->connection->host->warningsLogWrite (_("Http: internal error"));
               return 1;
             }
         }
 
       if (size && chain->write (buffer, size, &nbw))
         {
-          td->connection->host->warningsLogWrite ("HTTP<DATA HANDLER ERROR>: unable to write data in the filters chain.");
+          td->connection->host->warningsLogWrite (_("Http: internal error"));
           return 1;
         }
 
       if (useChunks && chain->getStream ()->write ("\r\n", 2, &nbw))
         {
-          td->connection->host->warningsLogWrite ("HTTP<DATA HANDLER ERROR>: unable to write data in the filters chain.");
+          td->connection->host->warningsLogWrite (_("Http: internal error"));
           return 1;
         }
 
