@@ -6,7 +6,7 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 
-This program is distributed in the hope that it will be useful, 
+This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
@@ -30,7 +30,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <include/protocol/ftp/ftp.h>
 
 #ifndef WIN32
-extern "C" 
+extern "C"
 {
 # include <sys/socket.h>
 # include <netinet/in.h>
@@ -48,7 +48,7 @@ extern "C"
 #endif
 
 /*!
- *Construct the object.
+ * Construct the object.
  */
 ClientsThread::ClientsThread (Server* server)
 {
@@ -58,41 +58,24 @@ ClientsThread::ClientsThread (Server* server)
   toDestroy = false;
   staticThread = 0;
   nBytesToRead = 0;
-
-  httpParser = NULL;
-  httpsParser = NULL;
-  controlProtocolParser = NULL;
-  ftpParser = NULL;
 }
 
 /*!
  *Destroy the ClientsThread object.
  */
-ClientsThread::~ClientsThread()
+ClientsThread::~ClientsThread ()
 {
   if (!initialized)
     return;
 
   threadIsRunning = false;
 
-  if (httpParser)
-    delete httpParser;
-
-  if (httpsParser)
-    delete httpsParser;
-
-  if (controlProtocolParser)
-    delete controlProtocolParser;
-
-  if (ftpParser)
-    delete ftpParser;
-
   buffer.free ();
-  secondaryBuffer.free ();
+  auxiliaryBuffer.free ();
 }
 
 /*!
- *Get the timeout value.
+ * Get the timeout value.
  */
 int ClientsThread::getTimeout ()
 {
@@ -100,8 +83,8 @@ int ClientsThread::getTimeout ()
 }
 
 /*!
- *Set the timeout value for the thread.
- *\param newTimeout The new timeout value.
+ * Set the timeout value for the thread.
+ * \param newTimeout The new timeout value.
  */
 void ClientsThread::setTimeout (int newTimeout)
 {
@@ -109,11 +92,11 @@ void ClientsThread::setTimeout (int newTimeout)
 }
 
 /*!
- *This function starts a new thread controlled by a ClientsThread 
- *class instance.
- *\param pParam Params to pass to the new thread.
+ * This function starts a new thread controlled by a ClientsThread
+ * class instance.
+ * \param pParam Params to pass to the new thread.
  */
-DEFINE_THREAD(clients_thread, pParam)
+DEFINE_THREAD (clients_thread, pParam)
 {
 #ifndef WIN32
   /* Block SigTerm, SigInt, and SigPipe in threads.  */
@@ -137,13 +120,13 @@ DEFINE_THREAD(clients_thread, pParam)
 
   ct->threadIsRunning = true;
   ct->threadIsStopped = false;
-  ct->buffersize = ct->server->getBuffersize ();
-  ct->secondaryBufferSize = ct->server->getBuffersize2 ();
-  
-  ct->buffer.setLength (ct->buffersize);
-  ct->buffer.m_nSizeLimit = ct->buffersize;
-  ct->secondaryBuffer.setLength (ct->secondaryBufferSize);
-  ct->secondaryBuffer.m_nSizeLimit = ct->secondaryBufferSize;
+  ct->bufferSize = ct->server->getBuffersize ();
+
+  ct->buffer.setRealLength (ct->bufferSize);
+  ct->buffer.setSizeLimit (ct->bufferSize);
+
+  ct->auxiliaryBuffer.setRealLength (ct->bufferSize);
+  ct->auxiliaryBuffer.setSizeLimit (ct->bufferSize);
 
   /* Built-in protocols will be initialized at the first use.  */
   ct->initialized = true;
@@ -151,11 +134,11 @@ DEFINE_THREAD(clients_thread, pParam)
   ct->server->increaseFreeThread ();
 
   /* Wait that the server is ready before go in the running loop.  */
-  while (!ct->server->isServerReady() && ct->threadIsRunning)
-    Thread::wait(500);
+  while (!ct->server->isServerReady () && ct->threadIsRunning)
+    Thread::wait (500);
 
   /*
-   * This function when is alive only call the controlConnections(...) function
+   * This function when is alive only call the controlConnections (...) function
    * of the ClientsThread class instance used for control the thread.
    */
   while (ct->threadIsRunning)
@@ -174,7 +157,7 @@ DEFINE_THREAD(clients_thread, pParam)
 
           ret = ct->controlConnections ();
           ct->server->increaseFreeThread ();
-          ct->busy = 0;
+          ct->busy = false;
 
           /*
            *The thread served the connection, so update the timeout value.
@@ -184,16 +167,13 @@ DEFINE_THREAD(clients_thread, pParam)
         }
       catch (bad_alloc &ba)
         {
-          ostringstream s;
-          s << "Bad alloc: " << ba.what();
-
-          ct->server->logWriteln  (s.str ().c_str (), MYSERVER_LOG_MSG_ERROR);
+          ct->server->log (MYSERVER_LOG_MSG_ERROR, _("Bad alloc: %s"),
+                                  ba.what ());
         }
       catch (exception &e)
         {
-          ostringstream s;
-          s << "Error: " << e.what ();
-          ct->server->logWriteln (s.str ().c_str (), MYSERVER_LOG_MSG_ERROR);
+          ct->server->log (MYSERVER_LOG_MSG_ERROR, _("Error : %s"),
+                                  e.what ());
         };
   }
 
@@ -205,8 +185,7 @@ DEFINE_THREAD(clients_thread, pParam)
 }
 
 /*!
- *Join the thread.
- *
+ * Join the thread.
  */
 int ClientsThread::join ()
 {
@@ -215,7 +194,7 @@ int ClientsThread::join ()
 
 
 /*!
- *Create the new thread.
+ * Create the new thread.
  */
 int ClientsThread::run ()
 {
@@ -225,24 +204,24 @@ int ClientsThread::run ()
 }
 
 /*!
- *Returns if the thread can be destroyed.
+ * Returns if the thread can be destroyed.
  */
-bool ClientsThread::isToDestroy()
+bool ClientsThread::isToDestroy ()
 {
   return toDestroy;
 }
 
 /*!
- *Check if the thread is a static one.
+ * Check if the thread is a static one.
  */
-bool ClientsThread::isStatic()
+bool ClientsThread::isStatic ()
 {
   return staticThread;
 }
 
 /*!
- *Set the thread to be static.
- *\param value The new static value.
+ * Set the thread to be static.
+ * \param value The new static value.
  */
 void ClientsThread::setStatic (bool value)
 {
@@ -250,27 +229,25 @@ void ClientsThread::setStatic (bool value)
 }
 
 /*!
- *Set if the thread can be destroyed.
- *\param value The new destroy value.
+ * Set if the thread can be destroyed.
+ * \param value The new destroy value.
  */
-void ClientsThread::setToDestroy(bool value)
+void ClientsThread::setToDestroy (bool value)
 {
   toDestroy = value;
 }
 
 /*!
- *This is the main loop of the thread.
- *Here are controlled all the connections that belongs to the 
- *ClientsThread class instance.
- *Every connection is controlled by its protocol.
- *Return 1 if no connections to serve are available.
- *Return 0 in all other cases.
+ * This is the main loop of the thread.
+ * Here are controlled all the connections that belongs to the
+ * ClientsThread class instance.
+ * Every connection is controlled by its protocol.
+ *\return 1 if no connections to serve are available.
+ *\return 0 in all other cases.
  */
 int ClientsThread::controlConnections ()
 {
-  /*
-   *Control the protocol used by the connection.
-   */
+  /* Control the protocol used by the connection.  */
   int retcode = 0;
   int err = 0;
   ConnectionPtr c;
@@ -281,40 +258,37 @@ int ClientsThread::controlConnections ()
 
   server->decreaseFreeThread ();
 
-  /*
-   *Check if c is a valid connection structure.
-   */
   if (!c)
     return 1;
 
-  busy = 1;
+  busy = true;
   dataRead = c->getConnectionBuffer ()->getLength ();
 
-  err = c->socket->recv(&((char*)(buffer.getBuffer()))[dataRead],
-                        MYSERVER_KB(8) - dataRead - 1, 0);
+  err = c->socket->recv (&((char*)(buffer.getBuffer ()))[dataRead],
+                        MYSERVER_KB (8) - dataRead - 1, 0);
 
-  if(err == -1 && !server->deleteConnection(c))
+  if (err == -1 && !server->deleteConnection (c))
     return 0;
 
-  buffer.setLength (dataRead + err);
+  buffer.setRealLength (dataRead + err);
   c->setForceControl (0);
 
   /* Refresh with the right value.  */
   nBytesToRead = dataRead + err;
 
   if ((dataRead + err) < MYSERVER_KB (8))
-    ((char*)buffer.getBuffer())[dataRead + err] = '\0';
+    ((char*)buffer.getBuffer ())[dataRead + err] = '\0';
   else
     {
       server->deleteConnection (c);
       return 0;
     }
 
-  if (getTicks() - c->getTimeout () > 5000)
+  if (getTicks () - c->getTimeout () > 5000)
     c->setnTries (0);
 
   if (dataRead)
-    memcpy ((char*)buffer.getBuffer(), c->getConnectionBuffer ()->getBuffer (),
+    memcpy ((char*)buffer.getBuffer (), c->getConnectionBuffer ()->getBuffer (),
             dataRead);
 
   c->setActiveThread (this);
@@ -322,10 +296,10 @@ int ClientsThread::controlConnections ()
   {
     if (c->hasContinuation ())
       {
-        retcode = c->getContinuation ()(c, (char*)buffer.getBuffer(), 
-                                   (char*)secondaryBuffer.getBuffer(), 
-                                   buffer.getRealLength(), 
-                                   secondaryBuffer.getRealLength(), 
+        retcode = c->getContinuation ()(c, (char*)buffer.getBuffer (),
+                                   (char*)auxiliaryBuffer.getBuffer (),
+                                   buffer.getRealLength (),
+                                   auxiliaryBuffer.getRealLength (),
                                    nBytesToRead, id);
         c->setContinuation (NULL);
       }
@@ -333,15 +307,13 @@ int ClientsThread::controlConnections ()
       {
         protocol = server->getProtocol (c->host->getProtocolName ());
         if (protocol)
-          {
-            retcode = protocol->controlConnection (c, (char*)buffer.getBuffer(),
-                                             (char*)secondaryBuffer.getBuffer(), 
-                                              buffer.getRealLength(), 
-                                             secondaryBuffer.getRealLength(), 
-                                             nBytesToRead, id);
-          }
+          retcode = protocol->controlConnection (c, (char*)buffer.getBuffer (),
+                                           (char*)auxiliaryBuffer.getBuffer (),
+                                           buffer.getRealLength (),
+                                           auxiliaryBuffer.getRealLength (),
+                                           nBytesToRead, id);
         else
-          retcode = DELETE_CONNECTION;
+          retcode = ClientsThread::DELETE_CONNECTION;
       }
   }
   catch (...)
@@ -367,9 +339,9 @@ int ClientsThread::controlConnections ()
   else if (retcode == INCOMPLETE_REQUEST)
     {
       /*
-       *If the header is incomplete save the current received
-       *data in the connection buffer.
-       *Save the header in the connection buffer.
+       * If the header is incomplete save the current received
+       * data in the connection buffer.
+       * Save the header in the connection buffer.
        */
       c->getConnectionBuffer ()->setBuffer (buffer.getBuffer (), nBytesToRead);
       server->getConnectionsScheduler ()->addWaitingConnection (c);
@@ -387,7 +359,7 @@ int ClientsThread::controlConnections ()
 /*!
  * Stop the thread.
  */
-void ClientsThread::stop()
+void ClientsThread::stop ()
 {
   /*
    * Set the run flag to False.
@@ -424,9 +396,9 @@ MemBuf* ClientsThread::getBuffer ()
 /*!
  * Get a pointer to the secondary buffer.
  */
-MemBuf *ClientsThread::getSecondaryBuffer ()
+MemBuf *ClientsThread::getAuxiliaryBuffer ()
 {
-  return &secondaryBuffer;
+  return &auxiliaryBuffer;
 }
 
 /*!
