@@ -1,20 +1,21 @@
 /*
- MyServer
- Copyright (C) 2008, 2009 Free Software Foundation, Inc.
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 3 of the License, or
- (at your option) any later version.
- 
- This program is distributed in the hope that it will be useful, 
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
- 
- You should have received a copy of the GNU General Public License
- along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
- 
+  MyServer
+  Copyright (C) 2008, 2009 Free Software Foundation, Inc.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
+
+#include "stdafx.h"
 #include <cppunit/CompilerOutputter.h>
 #include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/ui/text/TestRunner.h>
@@ -35,82 +36,105 @@ class TestFile : public CppUnit::TestFixture
 {
   File *tfile;
   string fname;
-  
-  CPPUNIT_TEST_SUITE ( TestFile );
 
-  CPPUNIT_TEST ( testCreateTemporaryFile );
-  CPPUNIT_TEST ( testOnFile );
-  CPPUNIT_TEST ( testTruncate );
+  CPPUNIT_TEST_SUITE (TestFile);
 
+  CPPUNIT_TEST (testCreateTemporaryFile);
+  CPPUNIT_TEST (testOnFile);
+  CPPUNIT_TEST (testTruncate);
+  CPPUNIT_TEST (testCreationTime);
+  CPPUNIT_TEST (testLastAccessTime);
+  CPPUNIT_TEST (testLastModTime);
+  CPPUNIT_TEST (testSeek);
   CPPUNIT_TEST_SUITE_END ();
 
+  int openHelper ()
+  {
+   return  tfile->openFile (fname.c_str (), File::WRITE
+                            | File::READ
+                            | File::FILE_CREATE_ALWAYS);
+  }
 public:
   void setUp ()
   {
-    setcwdBuffer ();/* Be sure the cwd buffer is initialized.  */
     FilesUtility::temporaryFileName (0, fname);
     tfile = new File;
   }
-  
+
   void tearDown ()
   {
     delete tfile;
+    FilesUtility::deleteFile (fname);
   }
-  
+
   void testCreateTemporaryFile ()
   {
-    CPPUNIT_ASSERT_EQUAL (tfile->createTemporaryFile (fname.c_str()), 0);
-    
+    CPPUNIT_ASSERT_EQUAL (tfile->createTemporaryFile (fname.c_str ()), 0);
+
     CPPUNIT_ASSERT_EQUAL (tfile->close (), 0);
   }
-  
+
   void testOnFile ()
   {
-    char buf[] = { 'H', 'e', 'l', 'l', 'o', ',', ' ', 'm', 'y', 'W', 'o', 'r', 'l', 'd', 0 };
-    const int bufLen = sizeof (buf) / sizeof (char);
+    const char *buf = "HELLO myWORLD";
+    char readbuf[512];
+    size_t bufLen = strlen (buf);
     u_long nbw;
     u_long nbr;
 
-    CPPUNIT_ASSERT_EQUAL (tfile->openFile (fname.c_str (), File::WRITE | 
-                                           File::READ | 
-                                           File::FILE_CREATE_ALWAYS), 0);
+    CPPUNIT_ASSERT_EQUAL (openHelper (), 0);
 
     CPPUNIT_ASSERT_EQUAL (tfile->writeToFile (buf, bufLen, &nbw), 0);
-    
-    memset (buf, 0, bufLen);
+
+    memset (readbuf, 0, bufLen);
 
     CPPUNIT_ASSERT_EQUAL (tfile->seek (0), 0);
 
-    CPPUNIT_ASSERT_EQUAL (tfile->read (buf, bufLen, &nbr), 0);
+    CPPUNIT_ASSERT_EQUAL (tfile->read (readbuf, bufLen, &nbr), 0);
 
     CPPUNIT_ASSERT (nbr > 0);
 
-    CPPUNIT_ASSERT (tfile->getCreationTime () != -1);
-
-    CPPUNIT_ASSERT (tfile->getLastAccTime () != -1);
-
-    CPPUNIT_ASSERT (tfile->getLastModTime () != -1);
-
-    CPPUNIT_ASSERT (tfile->getFileSize () != -1);
-
-    CPPUNIT_ASSERT_EQUAL (tfile->seek (1), 0);
-
-    CPPUNIT_ASSERT_EQUAL (tfile->getSeek (), 1ul);
+    for (size_t i = 0; i < bufLen; i++)
+      CPPUNIT_ASSERT_EQUAL (buf[i], readbuf[i]);
 
+    CPPUNIT_ASSERT_EQUAL (tfile->getFileSize (), nbr);
     CPPUNIT_ASSERT_EQUAL (tfile->close (), 0);
 
     FilesUtility::deleteFile (fname.c_str ());
   }
 
+  void testCreationTime ()
+  {
+    CPPUNIT_ASSERT_EQUAL (openHelper (), 0);
+    CPPUNIT_ASSERT (tfile->getCreationTime () != -1);
+  }
+
+  void testLastAccessTime ()
+  {
+    CPPUNIT_ASSERT_EQUAL (openHelper (), 0);
+    CPPUNIT_ASSERT (tfile->getCreationTime () != -1);
+  }
+
+  void testLastModTime ()
+  {
+    CPPUNIT_ASSERT_EQUAL (openHelper (), 0);
+    CPPUNIT_ASSERT (tfile->getCreationTime () != -1);
+  }
+
+  void testSeek ()
+  {
+    CPPUNIT_ASSERT_EQUAL (openHelper (), 0);
+    CPPUNIT_ASSERT_EQUAL (tfile->seek (1), 0);
+    CPPUNIT_ASSERT_EQUAL (tfile->getSeek (), 1ul);
+  }
+
   void testTruncate ()
   {
     u_long nbw;
 
     CPPUNIT_ASSERT_EQUAL (FilesUtility::deleteFile (fname.c_str ()), 0);
 
-    CPPUNIT_ASSERT_EQUAL (tfile->openFile (fname.c_str (), File::WRITE | 
-                                           File::READ | 
-                                           File::FILE_CREATE_ALWAYS), 0);
+    CPPUNIT_ASSERT_EQUAL (openHelper (), 0);
 
     CPPUNIT_ASSERT_EQUAL (tfile->getFileSize (), 0ul);
 
